import request from '@/utils/request'

// 查询组合数据列表
export function listGroup(query) {
    return request({
        url: '/mapi/system/group/list',
        method: 'get',
        params: query
    })
}

// 查询组合数据详细
export function getGroup(id) {
    return request({
        url: '/mapi/system/group/' + id,
        method: 'get'
    })
}

// 新增组合数据
export function addGroup(data) {
    return request({
        url: '/mapi/system/group',
        method: 'post',
        data: data
    })
}

// 修改组合数据
export function updateGroup(data) {
    return request({
        url: '/mapi/system/group',
        method: 'put',
        data: data
    })
}

// 删除组合数据
export function delGroup(id) {
    return request({
        url: '/mapi/system/group/' + id,
        method: 'delete'
    })
}


/**
 * @description 组合数据--新增
 * @param {Object} param data {Object} 传值参数
 */
export function groupAddApi(data) {
    return request({
      url: data.url,
      method: data.method,
      data: data.datas,
    });
  }
  
  /**
   * @description 组合数据--详情
   * @param {Number} param id {Number} 组合数据id
   */
  export function groupInfoApi(id) {
    return request({
      url: `/mapi/system/group/${id}`,
      method: 'get',
    });
  }

// 修改组合数据状态
export function updateGroupStatus(id,status) {
    const data = {
        id,
        status
    }
    return request({
        url: '/mapi/system/group/updateStatus',
        method: 'post',
        data: data
    })
}


/**
 * @description 组合数据列表
 * @param {Number} param id {Number} 组合数据id
 */
export function groupDataListApi(data) {
    return request({
      url: `/mapi/system/group/data/list`,
      method: 'get',
      params: data
    });
  }
  
  /**
   * @description 组合数据列表 -- 新增表单
   * @param {Number} param id {Number} 组合数据id
   */
  export function groupDataAddApi(id) {
    return request({
      url: `/mapi/system/group/data/createForm`,
      method: 'get',
      params: id,
    });
  }
  
  /**
   * @description 组合数据列表 -- 编辑表单
   * @param {Number} param id {Number} 组合数据列表id
   * @param {Object} param data {Object} 组合数据id对象
   */
  export function groupDataEditApi(data) {
    return request({
      url: '/mapi/system/group/data/editForm',
      method: 'get',
      params: data,
    });
  }
  
  /**
   * @description 组合数据列表 -- 编辑表单
   * @param {Number} param id {Number} 组合数据id
   */
  export function groupDataHeaderApi(data) {
    return request({
        url: `/mapi/system/group/header/info`,
      method: 'get',
      params: data,
    });
  }
  
  /**
   * @description 组合数据列表 -- 修改状态
   * @param {Object} param data {Object} 组合数据列表传值
   */
  export function groupDataSetApi(url) {
    return request({
      url: `/mapi/system/group/data`+url,
      method: 'POST',
    });
  }

  // 删除充值卡版本
export function delDataRecord(id) {
  return request({
    url: '/mapi/system/group/data/delete/' + id,
    method: 'delete'
  })
}